@@ -1,6 +1,5 @@
 from pyspark.ml.feature import StringIndexer
-from pyspark.shell import spark
-from pyspark.sql import DataFrame, Window
+from pyspark.sql import DataFrame, Window, SparkSession
 from pyspark.sql.functions import to_date, dayofmonth, month, row_number, avg, lead, desc, datediff, max
 from pyspark.sql.types import DoubleType, IntegerType
 
@@ -73,6 +72,7 @@ class Encoder:
 
     @staticmethod
     def _flatten_df(df: DataFrame) -> DataFrame:
+        spark = SparkSession.builder.getOrCreate()
         query = f"""
             SELECT
                 df1.{TITLE} {TITLE},
